@@ -2,6 +2,8 @@
  * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
  * SPDX-License-Identifier: Apache-2.0.
  */
+#ifndef AWS_COMMON_RESOURCE_NAME_H
+#define AWS_COMMON_RESOURCE_NAME_H
 #pragma once
 
 #include <aws/common/byte_buf.h>
@@ -22,7 +24,7 @@ AWS_EXTERN_C_BEGIN
     structure representing the parts
 */
 AWS_COMMON_API
-int aws_resource_name_init_from_cur(struct aws_resource_name *arn, const struct aws_byte_cursor *string);
+int aws_resource_name_init_from_cur(struct aws_resource_name *arn, const struct aws_byte_cursor *input);
 
 /**
     Calculates the space needed to write an ARN to a byte buf
@@ -37,3 +39,5 @@ AWS_COMMON_API
 int aws_byte_buf_append_resource_name(struct aws_byte_buf *buf, const struct aws_resource_name *arn);
 
 AWS_EXTERN_C_END
+
+#endif /* AWS_COMMON_RESOURCE_NAME_H */
